@@ -3,6 +3,15 @@ Short transient grid search
 ===========================
 
 An example grid-based search for a short transient signal.
+By default, the standard persistent-CW 2F-statistic
+and the transient max2F statistic are compared.
+
+You can turn on either `BSGL = True` or `BtSG = True` (not both!)
+to test alternative statistics.
+
+This is also ready to use on a GPU,
+if you have one available and `pycuda` installed.
+Just change to `tCWFstatMapVersion = "pycuda"`.
 """
 
 import os
@@ -12,6 +21,8 @@ import PyFstat_example_make_data_for_short_transient_search as data
 
 import pyfstat
 
+tCWFstatMapVersion = "lal"
+
 if __name__ == "__main__":
 
     if not os.path.isdir(data.outdir) or not np.any(
@@ -33,10 +44,11 @@ if __name__ == "__main__":
     Deltas = [data.Delta]
 
     BSGL = False
+    BtSG = False
 
     print("Standard CW search:")
     search1 = pyfstat.GridSearch(
-        label="CW" + ("_BSGL" if BSGL else ""),
+        label=f"CW{'_BSGL' if BSGL else ''}",
         outdir=data.outdir,
         sftfilepattern=os.path.join(data.outdir, "*simulated_transient_signal*sft"),
         F0s=F0s,
@@ -49,11 +61,14 @@ if __name__ == "__main__":
     )
     search1.run()
     search1.print_max_twoF()
-    search1.plot_1D(xkey="F0", xlabel="freq [Hz]", ylabel="$2\\mathcal{F}$")
+    search1.plot_1D(
+        xkey="F0", xlabel="freq [Hz]", ylabel=search1.tex_labels[search1.detstat]
+    )
 
     print("with t0,tau bands:")
+    label = f"tCW{'_BSGL' if BSGL else ''}{'_BtSG' if BtSG else ''}_FstatMap_{tCWFstatMapVersion}"
     search2 = pyfstat.TransientGridSearch(
-        label="tCW" + ("_BSGL" if BSGL else ""),
+        label=label,
         outdir=data.outdir,
         sftfilepattern=os.path.join(data.outdir, "*simulated_transient_signal*sft"),
         F0s=F0s,
@@ -66,9 +81,12 @@ if __name__ == "__main__":
         t0Band=data.duration - 2 * data.Tsft,
         tauBand=data.duration,
         outputTransientFstatMap=True,
-        tCWFstatMapVersion="lal",
+        tCWFstatMapVersion=tCWFstatMapVersion,
         BSGL=BSGL,
+        BtSG=BtSG,
     )
     search2.run()
     search2.print_max_twoF()
-    search2.plot_1D(xkey="F0", xlabel="freq [Hz]", ylabel="$2\\mathcal{F}$")
+    search2.plot_1D(
+        xkey="F0", xlabel="freq [Hz]", ylabel=search2.tex_labels[search2.detstat]
+    )
