@@ -12,7 +12,6 @@ import logging
 import os
 import shutil
 import subprocess
-import sys
 from datetime import datetime, timezone
 from functools import wraps
 
@@ -37,21 +36,8 @@ else:
     import matplotlib.pyplot as plt
 
 
-def set_up_optional_tqdm():
-    """Provides local replacement for tqdm if it cannot be imported."""
-    try:
-        from tqdm import tqdm
-    except ImportError:
-
-        def tqdm(x, *args, **kwargs):
-            return x
-
-    return tqdm
-
-
 def set_up_matplotlib_defaults():
     """Sets some defaults for matplotlib plotting."""
-    plt.rcParams["text.usetex"] = shutil.which("latex") is not None
     plt.rcParams["axes.formatter.useoffset"] = False
 
 
@@ -70,47 +56,7 @@ def set_up_command_line_arguments():
         action="store_true",
         help="Decrease output verbosity [logging.WARNING]",
     )
-    parser.add_argument(
-        "--no-interactive", help="Don't use interactive", action="store_true"
-    )
-    parser.add_argument(
-        "-c",
-        "--clean",
-        action="store_true",
-        help="Force clean data, never use cached data",
-    )
-    fu_parser = parser.add_argument_group(
-        "follow-up options", "Options related to MCMCFollowUpSearch"
-    )
-    fu_parser.add_argument(
-        "-s",
-        "--setup-only",
-        action="store_true",
-        help="Only generate the setup file, don't run",
-    )
-    fu_parser.add_argument(
-        "--no-template-counting",
-        action="store_true",
-        help="No counting of templates, useful if the setup is predefined",
-    )
-    parser.add_argument(
-        "-N",
-        type=int,
-        default=3,
-        metavar="N",
-        help="Number of threads to use when running in parallel",
-    )
-    parser.add_argument("unittest_args", nargs="*")
     args, unknown = parser.parse_known_args()
-    sys.argv[1:] = args.unittest_args
-
-    if args.quite or args.no_interactive:
-
-        def tqdm(x, *args, **kwargs):
-            return x
-
-    else:
-        tqdm = set_up_optional_tqdm()
 
     logger = logging.getLogger()
     stream_handler = logging.StreamHandler()
@@ -129,7 +75,7 @@ def set_up_command_line_arguments():
         stream_handler.setLevel(logging.INFO)
 
     logger.addHandler(stream_handler)
-    return args, tqdm
+    return args
 
 
 def get_ephemeris_files():
@@ -666,7 +612,7 @@ def get_doppler_params_output_format(keys):
 
     This uses the same format (`%.16g`) as
     the `write_FstatCandidate_to_fp()` function of
-    `lalapps_ComputeFstatistic_v2`.
+    the `ComputeFstatistic_v2` executable.
 
     This assigns that format to each parameter name in `keys`
     which matches a hardcoded list of known standard 'Doppler' parameters,
@@ -740,12 +686,16 @@ def read_txt_file_with_header(f, names=True, comments="#"):
     return data
 
 
-def get_lalapps_commandline_from_SFTDescriptor(descriptor):
-    """Extract a lalapps commandline from the 'comment' entry of a SFT descriptor.
+def get_commandline_from_SFTDescriptor(descriptor):
+    """Extract a commandline from the 'comment' entry of a SFT descriptor.
 
-    Most SFT creation tools save their commandline into that entry,
+    Most LALSuite SFT creation tools save their commandline into that entry,
     so we can extract it and reuse it to reproduce that data.
 
+    Since lalapps 9.0.0 / lalpulsar 5.0.0
+    the relevant executables have been moved to lalpulsar,
+    but we allow for lalapps backwards compatibility here,
+
     Parameters
     ----------
     descriptor: SFTDescriptor
@@ -754,8 +704,8 @@ def get_lalapps_commandline_from_SFTDescriptor(descriptor):
     Returns
     -------
     cmd: str
-        A lalapps commandline string,
-        or an empty string if 'lalapps' not found in comment.
+        A lalapps/lalpulsar commandline string,
+        or an empty string if no match in comment.
     """
     comment = getattr(descriptor, "comment", None)
     if comment is None:
@@ -763,7 +713,9 @@ def get_lalapps_commandline_from_SFTDescriptor(descriptor):
     comment_lines = comment.split("\n")
     # get the first line with the right substring
     # (iterate until it's found)
-    return next((line for line in comment_lines if "lalapps" in line), "")
+    return next(
+        (line for line in comment_lines if "lalpulsar" in line or "lalapps" in line), ""
+    )
 
 
 def read_parameters_dict_lines_from_file_header(
@@ -890,7 +842,7 @@ def read_par(
     Notes
     -----
     This can also be used to read in `.loudest` files
-    produced by `lalapps_ComputeFstatistic_v2`,
+    produced by the `ComputeFstatistic_v2` executable,
     or any file which has rows of `key=val` data
     (in which the val can be understood using `eval(val)`).
 
@@ -1027,12 +979,12 @@ def predict_fstat(
     transientStartTime=None,
     transientTau=None,
 ):
-    """Wrapper to lalapps_PredictFstat for predicting expected F-stat values.
+    """Wrapper to PredictFstat executable for predicting expected F-stat values.
 
     Parameters
     ----------
     h0, cosi, psi, Alpha, Delta : float
-        Signal parameters, see `lalapps_PredictFstat --help` for more info.
+        Signal parameters, see `lalpulsar_PredictFstat --help` for more info.
     F0: float or None
         Signal frequency.
         Only needed for noise floor estimation when given `sftfilepattern`
@@ -1061,17 +1013,17 @@ def predict_fstat(
         Required if `sftfilepattern=None`,
         optional otherwise..
     tempory_filename : str
-        Temporary file used for `lalapps_PredictFstat` output,
+        Temporary file used for `PredictFstat` output,
         will be deleted at the end.
     earth_ephem, sun_ephem : str or None
         Ephemerides files, defaults will be used if `None`.
     transientWindowType: str
         Optional parameter for transient signals,
-        see `lalapps_PredictFstat --help`.
+        see `lalpulsar_PredictFstat --help`.
         Default of `none` means a classical Continuous Wave signal.
     transientStartTime, transientTau: int or None
         Optional parameters for transient signals,
-        see `lalapps_PredictFstat --help`.
+        see `lalpulsar_PredictFstat --help`.
 
     Returns
     -------
@@ -1080,7 +1032,7 @@ def predict_fstat(
     """
 
     cl_pfs = []
-    cl_pfs.append("lalapps_PredictFstat")
+    cl_pfs.append(get_lal_exec("PredictFstat"))
 
     pars = {"h0": h0, "cosi": cosi, "psi": psi, "Alpha": Alpha, "Delta": Delta}
     cl_pfs.extend([f"--{key}={val}" for key, val in pars.items() if val is not None])
@@ -1181,7 +1133,7 @@ def generate_loudest_file(
     earth_ephem=None,
     sun_ephem=None,
 ):
-    """Use lalapps_ComputeFstatistic_v2 to produce a .loudest file.
+    """Use ComputeFstatistic_v2 executable to produce a .loudest file.
 
     Parameters
     -------
@@ -1224,7 +1176,7 @@ def generate_loudest_file(
         )
 
     loudest_file = os.path.join(outdir, label + ".loudest")
-    cmd = "lalapps_ComputeFstatistic_v2 "
+    cmd = get_lal_exec("ComputeFstatistic_v2")
     CFSv2_params = {
         "DataFiles": f'"{sftfilepattern}"',
         "outputLoudest": loudest_file,
@@ -1239,7 +1191,7 @@ def generate_loudest_file(
         "ephemSun": sun_ephem,
     }
     CFSv2_params.update({key: val for key, val in opt_params.items() if val})
-    cmd += " ".join([f"--{key}={val}" for key, val in CFSv2_params.items()])
+    cmd += " " + " ".join([f"--{key}={val}" for key, val in CFSv2_params.items()])
 
     run_commandline(cmd, return_output=False)
     return loudest_file
@@ -1277,3 +1229,30 @@ def gps_to_datestr_utc(gps):
         tzinfo=timezone.utc,
     )
     return dt.strftime("%c %Z")
+
+
+def get_lal_exec(cmd):
+    """Get a lalpulsar/lalapps executable name with the right prefix.
+
+    This is purely to allow for backwards compatibility
+    if, for whatever reason,
+    someone needs to run with old releases
+    (lalapps<9.0.0 and lalpulsar<5.0.0)
+    from before the executables were moved.
+
+    Parameters
+    -------
+    cmd: str
+        Base executable name without lalapps/lalpulsar prefix.
+
+    Returns
+    -------
+    full_cmd: str
+        Full executable name with the right prefix.
+    """
+    full_cmd = shutil.which("lalpulsar_" + cmd) or shutil.which("lalapps_" + cmd)
+    if full_cmd is None:
+        raise RuntimeError(
+            f"Could not find either lalpulsar or lalapps version of command {cmd}."
+        )
+    return os.path.basename(full_cmd)
