@@ -74,11 +74,24 @@ class pyTransientFstatMap:
         Maximum likelihood estimate of the transient start time `t0`.
     tau_ML: float
         Maximum likelihood estimate of the transient duration `tau`.
+    lnBtSG: float
+        Natural log of the marginalised transient Bayes factor.
+        NOTE: This is always initialised as `nan`,
+        and you have to call `get_lnBtSG()` to get its actual value.
     """
 
-    def __init__(self, N_t0Range=None, N_tauRange=None, transientFstatMap_t=None):
+    def __init__(
+        self,
+        N_t0Range=None,
+        N_tauRange=None,
+        transientFstatMap_t=None,
+        from_file=None,
+    ):
         """
-        The class can be initialized with the following:
+        The class can be initialized with either
+        a pair of (N_t0Range,N_tauRange),
+        from a lalpulsar object,
+        or reading from a file.
 
         Parameters
         ----------
@@ -87,10 +100,20 @@ class pyTransientFstatMap:
         N_tauRange: int
             Number of `tau` values covered.
         transientFstatMap_t: lalpulsar.transientFstatMap_t
-            pre-allocated matrix from lalpulsar.
+            pre-allocated matrix from lalpulsar to initialise from.
+        from_file: str or None
+            Text file,
+            compatible with `lalpulsar.write_transientFstatMap_to_fp()` format,
+            to load and initialise from.
         """
-        if transientFstatMap_t:
+        if transientFstatMap_t and from_file:  # pragma: no cover
+            raise ValueError(
+                "Please choose either a transientFstatMap_t or file to init from."
+            )
+        elif transientFstatMap_t:
             self._init_from_lalpulsar_type(transientFstatMap_t)
+        elif from_file:
+            self.read_from_file(from_file)
         else:
             if not N_t0Range or not N_tauRange:
                 raise ValueError(
@@ -104,14 +127,48 @@ class pyTransientFstatMap:
             self.maxF = float(-1.0)
             self.t0_ML = float(0.0)
             self.tau_ML = float(0.0)
+        self.lnBtSG = np.nan
 
     def _init_from_lalpulsar_type(self, transientFstatMap_t):
-        """This essentially just strips out a redundant member level from the lalpulsar structure."""
+        """This essentially just strips out a redundant member level from the lalpulsar structure.
+
+        Parameters
+        ----------
+        transientFstatMap_t: str
+            The lalpulsar structure to extract data from.
+        """
         self.F_mn = transientFstatMap_t.F_mn.data
         self.maxF = transientFstatMap_t.maxF
         self.t0_ML = transientFstatMap_t.t0_ML
         self.tau_ML = transientFstatMap_t.tau_ML
 
+    def read_from_file(self, file):
+        """Read F_mn map from a text file and set all other fields.
+
+        Apart from optional header lines (`#` comments),
+        the format has to be consistent with lalpulsar.write_transientFstatMap_to_fp()
+        and the `write_F_mn_to_file()` method of this class itself:
+        with the columns `[t0[s], tau[s], 2F]`.
+        NOTE that the file is expected to provide 2F,
+        so the values will be halved to obtain F for storage in this class.
+
+        Parameters
+        ----------
+        file: str
+            Name of the file to load from.
+        """
+        inarray = np.genfromtxt(
+            file,
+            comments="#",
+        )
+        t0s = np.unique(inarray[:, 0])
+        taus = np.unique(inarray[:, 1])
+        self.F_mn = (0.5 * inarray[:, 2]).reshape(len(t0s), len(taus))
+        maxidx = np.argmax(inarray[:, 2])
+        self.t0_ML = inarray[maxidx, 0]
+        self.tau_ML = inarray[maxidx, 1]
+        self.maxF = 0.5 * inarray[maxidx, 2]
+
     def get_maxF_idx(self):
         """Gets the 2D-unravelled index pair of the maximum of the F_mn map
 
@@ -122,11 +179,36 @@ class pyTransientFstatMap:
         """
         return np.unravel_index(np.argmax(self.F_mn), self.F_mn.shape)
 
+    def get_lnBtSG(self):
+        """Compute (natural log of the) transient-CW Bayes-factor B_tSG = P(x|HyptS)/P(x|HypG).
+
+        Here HypG = Gaussian noise hypothesis, HyptS = transient-CW signal hypothesis.
+
+        B_tSG is marginalized over start-time and timescale of transient CW signal,
+        using given type and parameters of transient window range.
+
+        This is a python port of the `lalpulsar.ComputeTransientBstat` implementation,
+        replacing `for` loops by numpy operations.
+        """
+        # The first 2 lines are equivalent to `logBhat = logsumexp(self.F_mn)`,
+        # but since we have `self.maxF` already precomputed,
+        # doing the manual version of the same stable summation trick is slightly faster.
+        sum_eB = np.sum(np.exp(-(self.maxF - self.F_mn)))
+        logBhat = self.maxF + np.log(sum_eB)  # unnormalized Bhat
+        normBh = 70.0 / np.prod(
+            self.F_mn.shape
+        )  # normalization factor assuming rhohMax=1
+        # NOTE: correct this for different rhohMax by adding "- 4 * log(rhohMax)" to lnBtSG
+        self.lnBtSG = np.log(normBh) + logBhat  # - 4.0 * log ( rhohMax )
+        return self.lnBtSG
+
     def write_F_mn_to_file(self, tCWfile, windowRange, header=[]):
         """Format a 2D transient-F-stat matrix over `(t0,tau)` and write as a text file.
 
         Apart from the optional extra header lines,
-        the format is consistent with lalpulsar.write_transientFstatMap_to_fp().
+        the format is consistent with lalpulsar.write_transientFstatMap_to_fp(),
+        with the columns `[t0[s], tau[s], 2F]`.
+        NOTE that the output is 2F, not F like stored in this class itself!
 
         Parameters
         ----------
@@ -152,11 +234,11 @@ class pyTransientFstatMap:
 
 
 fstatmap_versions = {
-    "lal": lambda multiFstatAtoms, windowRange: lalpulsar_compute_transient_fstat_map(
-        multiFstatAtoms, windowRange
+    "lal": lambda multiFstatAtoms, windowRange, BtSG: lalpulsar_compute_transient_fstat_map(
+        multiFstatAtoms, windowRange, BtSG
     ),
-    "pycuda": lambda multiFstatAtoms, windowRange: pycuda_compute_transient_fstat_map(
-        multiFstatAtoms, windowRange
+    "pycuda": lambda multiFstatAtoms, windowRange, BtSG: pycuda_compute_transient_fstat_map(
+        multiFstatAtoms, windowRange, BtSG
     ),
 }
 """Dictionary of the actual callable transient F-stat map functions this module supports.
@@ -166,7 +248,23 @@ being available.
 """
 
 
-def init_transient_fstat_map_features(wantCuda=False, cudaDeviceName=None):
+def _optional_imports_pycuda():
+    """Helper function to check for all all modules we need."""
+    have_pycuda = _optional_import("pycuda")
+    have_pycuda_drv = _optional_import("pycuda.driver", "drv")
+    have_pycuda_gpuarray = _optional_import("pycuda.gpuarray", "gpuarray")
+    have_pycuda_tools = _optional_import("pycuda.tools", "cudatools")
+    have_pycuda_compiler = _optional_import("pycuda.compiler", "cudacomp")
+    return (
+        have_pycuda
+        and have_pycuda_drv
+        and have_pycuda_gpuarray
+        and have_pycuda_tools
+        and have_pycuda_compiler
+    )
+
+
+def init_transient_fstat_map_features(feature="lal", cudaDeviceName=None):
     """Initialization of available modules (or 'features') for computing transient F-stat maps.
 
     Currently, two implementations are supported and checked for
@@ -180,9 +278,8 @@ def init_transient_fstat_map_features(wantCuda=False, cudaDeviceName=None):
 
     Parameters
     ----------
-    wantCuda: bool
-        Only if this is True and it was possible to import pycuda,
-        a CUDA device context is created and returned.
+    feature: str
+        Set the transient F-stat map implementation.
     cudaDeviceName: str or None
         Request a CUDA device with this name.
         Partial matches are allowed.
@@ -198,29 +295,16 @@ def init_transient_fstat_map_features(wantCuda=False, cudaDeviceName=None):
     """
 
     features = {}
-
     have_lal = _optional_import("lal")
     have_lalpulsar = _optional_import("lalpulsar")
     features["lal"] = have_lal and have_lalpulsar
-
-    # import GPU features
-    have_pycuda = _optional_import("pycuda")
-    have_pycuda_drv = _optional_import("pycuda.driver", "drv")
-    have_pycuda_gpuarray = _optional_import("pycuda.gpuarray", "gpuarray")
-    have_pycuda_tools = _optional_import("pycuda.tools", "cudatools")
-    have_pycuda_compiler = _optional_import("pycuda.compiler", "cudacomp")
-    features["pycuda"] = (
-        have_pycuda
-        and have_pycuda_drv
-        and have_pycuda_gpuarray
-        and have_pycuda_tools
-        and have_pycuda_compiler
-    )
-
+    features["pycuda"] = _optional_imports_pycuda()
     logging.debug("Got the following features for transient F-stat maps:")
     logging.debug(features)
 
-    if wantCuda and features["pycuda"]:
+    if feature == "pycuda":
+        if not features["pycuda"]:
+            raise RuntimeError("pycuda use was requested, but imports failed.")
         logging.debug("CUDA version: " + ".".join(map(str, drv.get_version())))
 
         drv.init()
@@ -308,14 +392,18 @@ def init_transient_fstat_map_features(wantCuda=False, cudaDeviceName=None):
             gpu_context.push()
 
         _print_GPU_memory_MB("Available")
-    else:
+    elif feature == "lal":
         gpu_context = None
+    else:
+        raise ValueError(
+            "Unknown transient F-stat map computation feature" f"'{feature}' requested."
+        )
 
     return features, gpu_context
 
 
 def call_compute_transient_fstat_map(
-    version, features, multiFstatAtoms=None, windowRange=None
+    version, features, multiFstatAtoms=None, windowRange=None, BtSG=False
 ):
     """Call a version of the ComputeTransientFstatMap function.
 
@@ -335,6 +423,10 @@ def call_compute_transient_fstat_map(
         The time-dependent F-stat atoms previously computed by `ComputeFstat`.
     windowRange: lalpulsar.transientWindowRange_t or None
         The structure defining the transient parameters.
+    BtSG: boolean
+        If true, also compute the lnBtSG transient Bayes factor statistic,
+        using the appropriate implementation for each feature,
+        and store it in `FstatMap.lnBtSG`.
 
     Returns
     -------
@@ -348,7 +440,7 @@ def call_compute_transient_fstat_map(
     if version in fstatmap_versions:
         if features[version]:
             time0 = time()
-            FstatMap = fstatmap_versions[version](multiFstatAtoms, windowRange)
+            FstatMap = fstatmap_versions[version](multiFstatAtoms, windowRange, BtSG)
             timingFstatMap = time() - time0
         else:
             raise Exception(
@@ -362,7 +454,7 @@ def call_compute_transient_fstat_map(
     return FstatMap, timingFstatMap
 
 
-def lalpulsar_compute_transient_fstat_map(multiFstatAtoms, windowRange):
+def lalpulsar_compute_transient_fstat_map(multiFstatAtoms, windowRange, BtSG=False):
     """Wrapper for the standard lalpulsar function for computing a transient F-statistic map.
 
     See https://lscsoft.docs.ligo.org/lalsuite/lalpulsar/_transient_c_w__utils_8h.html
@@ -374,6 +466,10 @@ def lalpulsar_compute_transient_fstat_map(multiFstatAtoms, windowRange):
         The time-dependent F-stat atoms previously computed by `ComputeFstat`.
     windowRange: lalpulsar.transientWindowRange_t
         The structure defining the transient parameters.
+    BtSG: boolean
+        If true, also compute the lnBtSG transient Bayes factor statistic,
+        using the corresponding lalpulsar function,
+        and store it in `FstatMap.lnBtSG`.
 
     Returns
     -------
@@ -385,7 +481,12 @@ def lalpulsar_compute_transient_fstat_map(multiFstatAtoms, windowRange):
         windowRange=windowRange,
         useFReg=False,
     )
-    return pyTransientFstatMap(transientFstatMap_t=FstatMap_lalpulsar)
+    FstatMap = pyTransientFstatMap(transientFstatMap_t=FstatMap_lalpulsar)
+    if BtSG:
+        FstatMap.lnBtSG = lalpulsar.ComputeTransientBstat(
+            windowRange, FstatMap_lalpulsar
+        )
+    return FstatMap
 
 
 def reshape_FstatAtomsVector(atomsVector):
@@ -407,27 +508,36 @@ def reshape_FstatAtomsVector(atomsVector):
 
     numAtoms = atomsVector.length
     atomsDict = {}
-    atom_fieldnames = [
-        "timestamp",
-        "Fa_alpha",
-        "Fb_alpha",
-        "a2_alpha",
-        "ab_alpha",
-        "b2_alpha",
+    tempDict = {}
+    atom_fields = [
+        ("timestamp", np.uint32),
+        ("a2_alpha", np.float32),
+        ("b2_alpha", np.float32),
+        ("ab_alpha", np.float32),
+        ("Fa_alpha", complex),
+        ("Fb_alpha", complex),
     ]
-    atom_dtypes = [np.uint32, complex, complex, np.float32, np.float32, np.float32]
-    for f, field in enumerate(atom_fieldnames):
-        atomsDict[field] = np.ndarray(numAtoms, dtype=atom_dtypes[f])
-
+    for dtype in atom_fields:
+        if dtype[1] == complex:
+            for part in "re", "im":
+                atomsDict[dtype[0] + "_" + part] = np.ndarray(
+                    numAtoms, dtype=np.float32
+                )
+            tempDict[dtype[0]] = np.ndarray(numAtoms, dtype=complex)
+        else:
+            atomsDict[dtype[0]] = np.ndarray(numAtoms, dtype=dtype[1])
     for n, atom in enumerate(atomsVector.data):
-        for field in atom_fieldnames:
-            atomsDict[field][n] = atom.__getattribute__(field)
-
-    atomsDict["Fa_alpha_re"] = np.float32(atomsDict["Fa_alpha"].real)
-    atomsDict["Fa_alpha_im"] = np.float32(atomsDict["Fa_alpha"].imag)
-    atomsDict["Fb_alpha_re"] = np.float32(atomsDict["Fb_alpha"].real)
-    atomsDict["Fb_alpha_im"] = np.float32(atomsDict["Fb_alpha"].imag)
-
+        for dtype in atom_fields:
+            if dtype[1] == complex:
+                tempDict[dtype[0]][n] = atom.__getattribute__(dtype[0])
+            else:
+                atomsDict[dtype[0]][n] = atom.__getattribute__(dtype[0])
+    for dtype in atom_fields:
+        if dtype[1] == complex:
+            for part in "real", "imag":
+                atomsDict[dtype[0] + "_" + part[:2]] = np.float32(
+                    getattr(tempDict[dtype[0]], part)
+                )
     return atomsDict
 
 
@@ -445,7 +555,7 @@ def _print_GPU_memory_MB(key):
     )
 
 
-def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange):
+def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange, BtSG=False):
     """GPU version of computing a transient F-statistic map.
 
     This is based on XLALComputeTransientFstatMap from LALSuite,
@@ -467,6 +577,10 @@ def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange):
         The time-dependent F-stat atoms previously computed by `ComputeFstat`.
     windowRange: lalpulsar.transientWindowRange_t
         The structure defining the transient parameters.
+    BtSG: boolean
+        If true, also compute the lnBtSG transient Bayes factor statistic,
+        using a CPU python port of the corresponding lalpulsar function,
+        and store it in `FstatMap.lnBtSG`.
 
     Returns
     -------
@@ -607,6 +721,11 @@ def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange):
         )
     )
 
+    if BtSG:
+        # so far seems there is no need to move this onto the GPU
+        FstatMap.lnBtSG = FstatMap.get_lnBtSG()
+        logging.debug(f"Also computed: lnBtSG={FstatMap.lnBtSG:.4f}")
+
     return FstatMap
 
 
