@@ -407,6 +407,134 @@ class TestComputeFstat(BaseForTestsWithData):
             log10BSGL == lalpulsar.ComputeBSGL(twoF, twoFX, search_H1L1_BSGL.BSGLSetup)
         )
 
+    def test_transient_detstats(self):
+        # first get maxTwoF and lnBtSG (from lalpulsar.ComputeTransientBstat) stats
+        CFS_params = {
+            "tref": self.tref,
+            "minStartTime": self.tstart,
+            "maxStartTime": self.tstart + self.duration,
+            "detectors": "H1,L1",
+            "injectSqrtSX": np.repeat(self.sqrtSX, 2),
+            "randSeed": 42,
+            "minCoverFreq": self.F0 - 0.1,
+            "maxCoverFreq": self.F0 + 0.1,
+            "transientWindowType": "rect",
+            "t0Band": 2 * default_Writer_params["Tsft"],
+            "tauBand": 2 * default_Writer_params["Tsft"],
+            "tauMin": 2 * default_Writer_params["Tsft"],
+            "tCWFstatMapVersion": "lal",
+        }
+        lambda_params = {
+            "F0": self.F0,
+            "F1": self.F1,
+            "F2": self.F2,
+            "Alpha": self.Alpha,
+            "Delta": self.Delta,
+        }
+        search1 = pyfstat.ComputeFstat(
+            **CFS_params,
+            BtSG=True,
+        )
+        # standard way of getting the "main" detection statistic (as set by BtSG=True)
+        lnBtSG1a = search1.get_fullycoherent_detstat(**lambda_params)
+        # twoF1 = search1.twoF
+        # maxTwoF1 = search1.maxTwoF
+        print(f"twoF={search1.twoF}, maxTwoF={search1.maxTwoF}")
+        # self.assertTrue(search1.maxTwoF >= search1.twoF) # FIXME: not always exactly true, can we define a more robust check?
+        # recompute BtSG by calling one function level lower,
+        # this should still redo the F-stat map and use the lalpulsar implementation
+        lnBtSG1b = search1.get_transient_detstats()
+        self.assertAlmostEqual(
+            lnBtSG1a,
+            lnBtSG1b,
+            places=4,
+            msg=f"lnBtSG: from get_fullycoherent_detstat() -> {lnBtSG1a}, from get_transient_detstats() -> {lnBtSG1b}",
+        )
+        # recompute BtSG from the F-stat map using our own implementation
+        lnBtSG1c = search1.FstatMap.get_lnBtSG()
+        self.assertAlmostEqual(
+            lnBtSG1a,
+            lnBtSG1b,
+            places=4,
+            msg=f"lnBtSG: from get_fullycoherent_detstat() -> {lnBtSG1a}, from FstatMap.get_lnBtSG() -> {lnBtSG1c}",
+        )
+        # recompute BtSG and other stats from a map saved to disk, using our own implementation
+        tCWfile = os.path.join(self.outdir, "Fmn.txt")
+        search1.FstatMap.write_F_mn_to_file(
+            tCWfile, search1.windowRange, "testing a header"
+        )
+        Fmap_from_file = pyfstat.pyTransientFstatMap(from_file=tCWfile)
+        Fmap_from_file.lnBtSG = Fmap_from_file.get_lnBtSG()
+        maxidx = Fmap_from_file.get_maxF_idx()
+        t0_ML = search1.windowRange.t0 + maxidx[0] * search1.windowRange.dt0
+        tau_ML = search1.windowRange.tau + maxidx[1] * search1.windowRange.dtau
+        shape1 = np.shape(search1.FstatMap.F_mn)
+        shape2 = np.shape(Fmap_from_file.F_mn)
+        self.assertTrue(
+            shape1 == shape2,
+            msg=f"shape(search1.FstatMap.F_mn)={shape1}, shape(Fmap_from_file.F_mn)={shape2}",
+        )
+        self.assertAlmostEqual(
+            search1.FstatMap.maxF,
+            Fmap_from_file.maxF,
+            places=4,
+            msg=f"search1.FstatMap.maxF={search1.FstatMap.maxF}, Fmap_from_file.maxF={Fmap_from_file.maxF}",
+        )
+        self.assertAlmostEqual(
+            search1.FstatMap.maxF,
+            Fmap_from_file.maxF,
+            places=4,
+            msg=f"search1.FstatMap.maxF={search1.FstatMap.maxF}, Fmap_from_file.maxF={Fmap_from_file.maxF}",
+        )
+        self.assertAlmostEqual(
+            search1.FstatMap.t0_ML,
+            t0_ML,
+            places=4,
+            msg=f"search1.FstatMap.t0_ML={search1.FstatMap.t0_ML}, from file: t0_ML={t0_ML}",
+        )
+        self.assertAlmostEqual(
+            search1.FstatMap.tau_ML,
+            tau_ML,
+            places=4,
+            msg=f"search1.FstatMap.tau_ML={search1.FstatMap.tau_ML}, from file: tau_ML={tau_ML}",
+        )
+        self.assertAlmostEqual(
+            search1.FstatMap.lnBtSG,
+            Fmap_from_file.lnBtSG,
+            places=2,  # more tolerant than other checks due to implementation details
+            msg=f"search1.FstatMap.lnBtSG={search1.FstatMap.lnBtSG}, Fmap_from_file.lnBtSG={Fmap_from_file.lnBtSG}",
+        )
+
+        # now set up for transient BSGL as "main" detection statistic instead
+        search2 = pyfstat.ComputeFstat(
+            **CFS_params,
+            BSGL=True,
+        )
+        log10BSGL2a = search2.get_fullycoherent_detstat(**lambda_params)
+        self.assertAlmostEqual(
+            search1.twoF,
+            search2.twoF,
+            places=4,
+            msg=f"search1.twoF={search1.twoF}, search2.twoF={search2.twoF}",
+        )
+        self.assertAlmostEqual(
+            search1.maxTwoF,
+            search2.maxTwoF,
+            places=4,
+            msg=f"search1.maxTwoF={search1.maxTwoF}, search2.maxTwoF={search2.maxTwoF}",
+        )
+        print(f"twoFXatMaxTwoF={search2.twoFXatMaxTwoF}")
+        print(f"log10BSGL={search2.log10BSGL}")
+        # recompute log10BSGL by calling one function level lower
+        log10BSGL2b = search2.get_transient_detstats()
+        self.assertAlmostEqual(
+            log10BSGL2a,
+            log10BSGL2b,
+            places=4,
+            msg=f"log10BSGL: from get_fullycoherent_detstat() -> {log10BSGL2a}, from get_transient_detstats() -> {log10BSGL2b}",
+        )
+        # FIXME: add more quantitative tests of BSGL values
+
     def test_cumulative_twoF(self):
         Nsft = 100
         # not using any SFTs on disk
@@ -497,6 +625,70 @@ class TestComputeFstat(BaseForTestsWithData):
         self.assertTrue(reldiffend < 0.25)
 
 
+@pytest.mark.parametrize("tCWFstatMapVersion", ["lal", "pycuda"])
+@pytest.mark.parametrize("transientWindowType", [None, "rect"])
+@pytest.mark.parametrize("cleanup", ["no", "manual", "contextmanager"])
+def test_context_finalizer(tCWFstatMapVersion, transientWindowType, cleanup):
+    CFS_params = {
+        "tref": default_Writer_params["tstart"],
+        "minStartTime": default_Writer_params["tstart"],
+        "maxStartTime": default_Writer_params["tstart"]
+        + default_Writer_params["duration"],
+        "detectors": default_Writer_params["detectors"],
+        "injectSqrtSX": default_Writer_params["sqrtSX"],
+        "minCoverFreq": default_signal_params["F0"] - 0.1,
+        "maxCoverFreq": default_signal_params["F0"] + 0.1,
+    }
+    lambda_params = {
+        "F0": default_signal_params["F0"],
+        "F1": default_signal_params["F1"],
+        "F2": default_signal_params["F2"],
+        "Alpha": default_signal_params["Alpha"],
+        "Delta": default_signal_params["Delta"],
+    }
+
+    if "cuda" not in tCWFstatMapVersion:
+        search = pyfstat.ComputeFstat(
+            **CFS_params,
+            tCWFstatMapVersion="lal",
+        )
+        assert search._finalizer is None
+        return
+
+    # if GPU available, try the real thing;
+    # else this should still set up the finalizer
+    # but without actually trying to run on GPU
+    have_pycuda = pyfstat.tcw_fstat_map_funcs._optional_imports_pycuda()
+    if have_pycuda:
+        if cleanup == "no":
+            pytest.skip("This case might work but will sabotage others.")
+    else:
+        pytest.skip("Optional imports failed, skipping actual pycuda test.")
+    if cleanup == "contextmanager":
+        with pyfstat.ComputeFstat(
+            **CFS_params,
+            tCWFstatMapVersion=tCWFstatMapVersion,
+            transientWindowType=transientWindowType,
+        ) as search:
+            assert search._finalizer is not None
+            assert search._finalizer.alive
+            detstat = search.get_fullycoherent_detstat(**lambda_params)
+    else:
+        search = pyfstat.ComputeFstat(
+            **CFS_params,
+            tCWFstatMapVersion=tCWFstatMapVersion,
+            transientWindowType=transientWindowType,
+        )
+        assert search._finalizer is not None
+        assert search._finalizer.alive
+        detstat = search.get_fullycoherent_detstat(**lambda_params)
+        if cleanup == "manual":
+            # calling finalizer manually should kill it
+            search._finalizer()
+            assert not search._finalizer.alive
+    assert detstat > 0
+
+
 class TestComputeFstatNoNoise(BaseForTestsWithData):
     # FIXME: should be possible to merge into TestComputeFstat with smart
     # defaults handlingf
